@@ -207,10 +207,6 @@ int feh_load_image(Imlib_Image * im, feh_file * file)
 	char *tmpname = NULL;
 	char *real_filename = NULL;
 
-#ifdef HAVE_LIBEXIF
-	ExifEntry *entry;
-#endif
-
 	D(("filename is %s, image is %p\n", file->filename, im));
 
 	if (!file || !file->filename)
@@ -283,7 +279,7 @@ int feh_load_image(Imlib_Image * im, feh_file * file)
 
 static char *feh_magick_load_image(char *filename)
 {
-	char argv_fd[12];
+	char *argv_fn;
 	char *basename;
 	char *tmpname;
 	char *sfn;
@@ -310,10 +306,17 @@ static char *feh_magick_load_image(char *filename)
 
 	fd = mkstemp(sfn);
 
-	if (fd == -1)
+	if (fd == -1) {
+		free(sfn);
 		return NULL;
+	}
 
-	snprintf(argv_fd, sizeof(argv_fd), "png:fd:%d", fd);
+	/*
+	 * We could use png:fd:(whatever mkstemp returned) as target filename
+	 * for convert, but this seems to be broken in some ImageMagick versions.
+	 * So we resort to png:(sfn) instead.
+	 */
+	argv_fn = estrjoin(":", "png", sfn, NULL);
 
 	if ((childpid = fork()) < 0) {
 		weprintf("%s: Can't load with imagemagick. Fork failed:", filename);
@@ -323,18 +326,20 @@ static char *feh_magick_load_image(char *filename)
 	}
 	else if (childpid == 0) {
 
-		/* discard convert output */
 		devnull = open("/dev/null", O_WRONLY);
 		dup2(devnull, 0);
-		dup2(devnull, 1);
-		dup2(devnull, 2);
+		if (opt.quiet) {
+			/* discard convert output */
+			dup2(devnull, 1);
+			dup2(devnull, 2);
+		}
 
 		/*
 		 * convert only accepts SIGINT via killpg, a normal kill doesn't work
 		 */
 		setpgid(0, 0);
 
-		execlp("convert", "convert", filename, argv_fd, NULL);
+		execlp("convert", "convert", filename, argv_fn, NULL);
 		_exit(1);
 	}
 	else {
@@ -367,6 +372,7 @@ static char *feh_magick_load_image(char *filename)
 		childpid = 0;
 	}
 
+	free(argv_fn);
 	return sfn;
 }
 
@@ -423,6 +429,10 @@ static char *feh_http_load_image(char *url)
 			if (opt.insecure_ssl) {
 				curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, 0);
 				curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, 0);
+			} else {
+				// Allow the user to specify custom CA certificates.
+				curl_easy_setopt(curl, CURLOPT_CAINFO,
+						getenv("CURL_CA_BUNDLE"));
 			}
 
 			res = curl_easy_perform(curl);
@@ -673,11 +683,12 @@ void feh_draw_exif(winwidget w)
 
 	fn = feh_load_font(w);
 
-	if (buffer == NULL)
+	if (buffer[0] == '\0')
 	{
 		snprintf(buffer, EXIF_MAX_DATA, "%s", estrdup("Failed to run exif command"));
-		gib_imlib_get_text_size(fn, &buffer[0], NULL, &width, &height, IMLIB_TEXT_TO_RIGHT);
-		no_lines = 1;
+		gib_imlib_get_text_size(fn, buffer, NULL, &width, &height, IMLIB_TEXT_TO_RIGHT);
+		info_buf[no_lines] = estrdup(buffer);
+		no_lines++;
 	}
 	else
 	{
@@ -1260,7 +1271,7 @@ void feh_draw_actions(winwidget w)
 	int i = 0;
 	int num_actions = 0;
 	int cur_action = 0;
-	char index[2];
+	char index[3];
 	char *line;
 
 	/* Count number of defined actions. This method sucks a bit since it needs
